@@ -16,7 +16,7 @@ use KinoSearch::Search::TermQuery;
 use Search::Query::Dialect::KSx::NOTWildcardQuery;
 use Search::Query::Dialect::KSx::WildcardQuery;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 __PACKAGE__->mk_accessors(
     qw(
@@ -154,7 +154,10 @@ sub stringify_clause {
     }
 
     # make sure we have a field
-    my $default_field = $self->default_field || $self->parser->default_field;
+    my $default_field 
+        = $self->default_field
+        || $self->parser->default_field
+        || undef;    # not empty string or 0
     my @fields
         = $clause->{field}
         ? ( $clause->{field} )
